@@ -23,22 +23,24 @@ const char* ffDetectCPUImpl(FF_MAYBE_UNUSED const FFCPUOptions* options, FFCPURe
 
     {
         kstat_named_t* kn = kstat_data_lookup(ks, "brand");
-        ffStrbufSetNS(&cpu->name, KSTAT_NAMED_STR_BUFLEN(kn) - 1, KSTAT_NAMED_STR_PTR(kn));
+        if (kn) ffStrbufSetNS(&cpu->name, KSTAT_NAMED_STR_BUFLEN(kn) - 1, KSTAT_NAMED_STR_PTR(kn));
     }
     {
         kstat_named_t* kn = kstat_data_lookup(ks, "vendor_id");
-        ffStrbufSetNS(&cpu->vendor, KSTAT_NAMED_STR_BUFLEN(kn) - 1, KSTAT_NAMED_STR_PTR(kn));
+        if (kn) ffStrbufSetNS(&cpu->vendor, KSTAT_NAMED_STR_BUFLEN(kn) - 1, KSTAT_NAMED_STR_PTR(kn));
     }
     ffCPUDetectSpeedByCpuid(cpu);
-    kstat_named_t* kn = kstat_data_lookup(ks, "clock_MHz");
-    if (kn->value.ui32 > cpu->frequencyBase)
-        cpu->frequencyBase = kn->value.ui32;
+    {
+        kstat_named_t* kn = kstat_data_lookup(ks, "clock_MHz");
+        if (kn && kn->value.ui32 > cpu->frequencyBase)
+            cpu->frequencyBase = kn->value.ui32;
+    }
 
     ks = kstat_lookup(kc, "unix", -1, "system_misc");
     if (ks && kstat_read(kc, ks, NULL) >= 0)
     {
         kstat_named_t* kn = kstat_data_lookup(ks, "ncpus");
-        cpu->coresLogical = cpu->coresPhysical = cpu->coresOnline = (uint16_t) kn->value.ui32;
+        if (kn) cpu->coresLogical = cpu->coresPhysical = cpu->coresOnline = (uint16_t) kn->value.ui32;
     }
 
     return NULL;
