@@ -153,6 +153,7 @@ static void printGPUResult(FFGPUOptions* options, uint8_t index, const FFGPUResu
             FF_FORMAT_ARG(sPercentBar, "shared-percentage-bar"),
             FF_FORMAT_ARG(coreUsageNum, "core-usage-num"),
             FF_FORMAT_ARG(coreUsageBar, "core-usage-bar"),
+            FF_FORMAT_ARG(gpu->memoryType, "memory-type"),
         }));
     }
 }
@@ -193,6 +194,7 @@ void ffPrintGPU(FFGPUOptions* options)
         ffStrbufDestroy(&gpu->name);
         ffStrbufDestroy(&gpu->driver);
         ffStrbufDestroy(&gpu->platformApi);
+        ffStrbufDestroy(&gpu->memoryType);
     }
 }
 
@@ -398,9 +400,6 @@ void ffGenerateGPUJsonResult(FFGPUOptions* options, yyjson_mut_doc* doc, yyjson_
         else
             yyjson_mut_obj_add_null(doc, dedicatedObj, "used");
 
-        yyjson_mut_obj_add_strbuf(doc, obj, "driver", &gpu->driver);
-        yyjson_mut_obj_add_strbuf(doc, obj, "name", &gpu->name);
-
         yyjson_mut_val* sharedObj = yyjson_mut_obj_add_obj(doc, memoryObj, "shared");
         if (gpu->shared.total != FF_GPU_VMEM_SIZE_UNSET)
             yyjson_mut_obj_add_uint(doc, sharedObj, "total", gpu->shared.total);
@@ -411,6 +410,14 @@ void ffGenerateGPUJsonResult(FFGPUOptions* options, yyjson_mut_doc* doc, yyjson_
         else
             yyjson_mut_obj_add_null(doc, sharedObj, "used");
 
+        if (gpu->memoryType.length)
+            yyjson_mut_obj_add_strbuf(doc, memoryObj, "type", &gpu->memoryType);
+        else
+            yyjson_mut_obj_add_null(doc, memoryObj, "type");
+
+        yyjson_mut_obj_add_strbuf(doc, obj, "driver", &gpu->driver);
+        yyjson_mut_obj_add_strbuf(doc, obj, "name", &gpu->name);
+
         if(gpu->temperature == gpu->temperature) //FF_GPU_TEMP_UNSET
             yyjson_mut_obj_add_real(doc, obj, "temperature", gpu->temperature);
         else
@@ -440,6 +447,7 @@ void ffGenerateGPUJsonResult(FFGPUOptions* options, yyjson_mut_doc* doc, yyjson_
         ffStrbufDestroy(&gpu->name);
         ffStrbufDestroy(&gpu->driver);
         ffStrbufDestroy(&gpu->platformApi);
+        ffStrbufDestroy(&gpu->memoryType);
     }
 }
 
@@ -469,8 +477,9 @@ static FFModuleBaseInfo ffModuleInfo = {
         {"Dedicated memory usage percentage bar", "dedicated-percentage-bar"},
         {"Shared memory usage percentage num", "shared-percentage-num"},
         {"Shared memory usage percentage bar", "shared-percentage-bar"},
-        {"Core usage percentage num (supports Nvidia & Apple GPU only)", "core-usage-num"},
-        {"Core usage percentage bar (supports Nvidia & Apple GPU only)", "core-usage-bar"},
+        {"Core usage percentage num", "core-usage-num"},
+        {"Core usage percentage bar", "core-usage-bar"},
+        {"Memory type (Windows only)", "memory-type"},
     })),
 };
 
